@@ -52,11 +52,29 @@ def test_validate_paths():
         with pytest.raises(ValueError, match=r".*The file/path.*not_a_real_file.*"):
             iou.validate_paths(wrong_file)
 
+    # make tempdir for testing outside of docker
+    with tempfile.TemporaryDirectory() as valid_path:
+
+        # make valid subdirectory
+        valid_parts = [p for p in pathlib.Path(valid_path).parts]
+        valid_parts[0] = 'not_a_real_directory'
+
+        # test no '../data' prefix
+        starts_out_of_scope = os.path.join(*valid_parts)
+
+        # test out of scope when specifying out of scope
+        with pytest.raises(ValueError, match=r".*not_a_real_directory*"):
+            iou.validate_paths(starts_out_of_scope, data_prefix=False)
+
+        with pytest.raises(ValueError, match=r".*is not prefixed with.*"):
+            iou.validate_paths(starts_out_of_scope, data_prefix=True)
+
     # reset cwd after testing
     os.chdir('../')
 
 
 def test_list_files():
+    # test extension matching
     with tempfile.TemporaryDirectory() as temp_dir:
         # set up temp_dir files
         filenames = [
@@ -73,21 +91,69 @@ def test_list_files():
 
         # test substrs is None (default)
         get_all = iou.list_files(temp_dir)
-        assert get_all.sort() == filenames.sort()
+        assert sorted(get_all) == sorted(filenames)
 
         # test substrs is not list (single string)
         get_txt = iou.list_files(temp_dir, substrs='.txt')
-        assert get_txt.sort() == filenames[0:2].sort()
+        assert sorted(get_txt) == sorted(filenames[0:2])
 
         # test substrs is list
-        get_test_and_other = iou.list_files(temp_dir, substrs=['test', 'other'])
-        assert get_test_and_other.sort() == filenames[1:].sort()
+        get_test_and_other = iou.list_files(temp_dir, substrs=['.txt', '.out'])
+        assert sorted(get_test_and_other) == sorted(filenames[:3])
+
+    # test file name exact matching
+    with tempfile.TemporaryDirectory() as temp_dir:
+        filenames = [
+            'chan0.tif',
+            'chan.tif',
+            'c.tif'
+        ]
+        for filename in filenames:
+            pathlib.Path(os.path.join(temp_dir, filename)).touch()
+
+        # add extra folder (shouldn't be picked up)
+        os.mkdir(os.path.join(temp_dir, 'badfolder_test'))
+
+        # test substrs is None (default)
+        get_all = iou.list_files(temp_dir, exact_match=True)
+        assert sorted(get_all) == sorted(filenames)
+
+        # test substrs is not list (single string)
+        get_txt = iou.list_files(temp_dir, substrs='c', exact_match=True)
+        assert sorted(get_txt) == [filenames[2]]
+
+        # test substrs is list
+        get_test_and_other = iou.list_files(temp_dir, substrs=['c', 'chan'], exact_match=True)
+        assert sorted(get_test_and_other) == sorted(filenames[1:])
+
+
+def test_remove_file_extensions():
+    # test a mixture of file paths and extensions
+    files = [
+        'fov1.tiff',
+        'fov2.tif',
+        'fov3.png',
+        'fov4.jpg'
+    ]
+
+    assert iou.remove_file_extensions(None) is None
+    assert iou.remove_file_extensions([]) == []
+
+    files_sans_ext = ['fov1', 'fov2', 'fov3', 'fov4']
+
+    new_files = iou.remove_file_extensions(files)
+
+    assert new_files == files_sans_ext
+
+    with pytest.warns(UserWarning):
+        new_files = iou.remove_file_extensions(['fov5.tar.gz', 'fov6.sample.csv'])
+        assert new_files == ['fov5.tar', 'fov6.sample']
 
 
 def test_extract_delimited_names():
     filenames = [
-        'fov1_restofname.txt',
-        'fov2.txt',
+        'fov1_restofname',
+        'fov2',
     ]
 
     # test no files given (None/[])
@@ -96,22 +162,10 @@ def test_extract_delimited_names():
 
     # non-optional delimiter warning
     with pytest.warns(UserWarning):
-        iou.extract_delimited_names(['fov2.txt'], delimiter_optional=False)
+        iou.extract_delimited_names(['fov2'], delimiter='_', delimiter_optional=False)
 
     # test regular files list
-    assert ['fov1', 'fov2'] == iou.extract_delimited_names(filenames)
-
-    # test fullpath list
-    fullpaths = [
-        os.path.join('folder_with_delims', filename)
-        for filename in filenames
-    ]
-    assert ['fov1', 'fov2'] == iou.extract_delimited_names(fullpaths)
-
-    # test mixed
-    assert ['fov1', 'fov2'] == iou.extract_delimited_names([fullpaths[0], filenames[1]])
-
-    return
+    assert ['fov1', 'fov2'] == iou.extract_delimited_names(filenames, delimiter='_')
 
 
 def test_list_folders():
